@@ -24,6 +24,7 @@
 __all__ = [ "ipset", "check_ipset_name", "remove_default_create_options" ]
 
 import os.path
+import ipaddress
 
 from firewall import errors
 from firewall.errors import FirewallError
@@ -137,7 +138,7 @@ class ipset(object):
         return self.__run([ "destroy", set_name ])
 
     def set_add(self, set_name, entry):
-        args = [ "add", set_name, entry, "-exist" ]
+        args = [ "add", set_name, entry ]
         return self.__run(args)
 
     def set_delete(self, set_name, entry):
@@ -219,15 +220,16 @@ class ipset(object):
                 if val != "":
                     args.append(val)
         temp_file.write("%s\n" % " ".join(args))
+        temp_file.write("flush %s\n" % set_name)
 
         for entry in entries:
             if ' ' in entry:
                 entry = "'%s'" % entry
             if entry_options:
-                temp_file.write("add %s %s %s -exist\n" % \
+                temp_file.write("add %s %s %s\n" % \
                                 (set_name, entry, " ".join(entry_options)))
             else:
-                temp_file.write("add %s %s -exist\n" % (set_name, entry))
+                temp_file.write("add %s %s\n" % (set_name, entry))
         temp_file.close()
 
         stat = os.stat(temp_file.name)
@@ -288,3 +290,28 @@ def remove_default_create_options(options):
            IPSET_DEFAULT_CREATE_OPTIONS[opt] == _options[opt]:
             del _options[opt]
     return _options
+
+def normalize_ipset_entry(entry):
+    """ Normalize IP addresses in entry """
+    _entry = []
+    for _part in entry.split(","):
+        try:
+            _part.index("/")
+            _entry.append(str(ipaddress.ip_network(_part, strict=False)))
+        except ValueError:
+            _entry.append(_part)
+
+    return ",".join(_entry)
+
+def check_entry_overlaps_existing(entry, entries):
+    """ Check if entry overlaps any entry in the list of entries """
+    # Only check simple types
+    if len(entry.split(",")) > 1:
+        return
+
+    for itr in entries:
+        try:
+            if ipaddress.ip_network(itr, strict=False).overlaps(ipaddress.ip_network(entry, strict=False)):
+                raise FirewallError(errors.INVALID_ENTRY, "Entry '{}' overlaps with existing entry '{}'".format(itr, entry))
+        except ValueError:
+            pass
